@@ -11,15 +11,23 @@ import re
 # Regular expressions for identifying inline markup.
 # ------------------------------------------------------------------------------
 
+# *x*
+re_italic_sc = re.compile(r"\*(\S)\*")
 
 # *foo bar*
-re_italic = re.compile(r"\*(\S(.*?\S)?)\*")
+re_italic_mc = re.compile(r"\*(\S.*?\S)\*")
+
+# **x**
+re_bold_sc = re.compile(r"\*{2}(\S)\*{2}")
 
 # **foo bar**
-re_bold = re.compile(r"\*{2}(\S(.*?\S)?)\*{2}")
+re_bold_mc = re.compile(r"\*{2}(\S.*?\S)\*{2}")
+
+# ***x***
+re_bolditalic_sc = re.compile(r"\*{3}(\S)\*{3}")
 
 # ***foo bar***
-re_bolditalic = re.compile(r"\*{3}(\S(.*?\S)?)\*{3}")
+re_bolditalic_mc = re.compile(r"\*{3}(\S.*?\S)\*{3}")
 
 # `foo bar`
 re_backticks = re.compile(r"`(.+?)`")
@@ -47,6 +55,7 @@ re_entity = re.compile(r"&[#a-zA-Z0-9]+;")
 
 # html tags: <span>, </span>, <!-- comment -->, etc.
 re_html = re.compile(r"<([a-zA-Z/][^>]*?|!--.*?--)>")
+
 # <http://example.com>
 re_bracketed_url = re.compile(r"<((?:https?|ftp)://[^>]+)>")
 
@@ -70,6 +79,9 @@ re_superscript = re.compile(r"\^\{(.+?)\}")
 # H_{2}O
 re_subscript = re.compile(r"_\{(.+?)\}")
 
+# ``foo bar``
+re_verbatim = re.compile(r"``(.+?)``")
+
 
 # ------------------------------------------------------------------------------
 # Renderers.
@@ -80,6 +92,7 @@ re_subscript = re.compile(r"_\{(.+?)\}")
 def render(text, meta):
     hashes = {}
 
+    text = render_verbatim(text, hashes)
     text = render_backticks(text, hashes)
     text = render_bracketed_urls(text, hashes)
     text = render_inline_html(text, hashes)
@@ -134,6 +147,10 @@ def render_inline_html(text, hashes):
     return re_html.sub(lambda match: hashstr(match.group(), hashes), text)
 
 
+def render_verbatim(text, hashes):
+    return re_verbatim.sub(lambda match: hashstr(match.group(1), hashes), text)
+
+
 def render_html_entities(text, hashes):
     return re_entity.sub(lambda match: hashstr(match.group(), hashes), text)
 
@@ -145,15 +162,21 @@ def render_dashes(text, hashes):
 
 
 def render_bold(text):
-    return re_bold.sub(r"<b>\1</b>", text)
+    text = re_bold_sc.sub(r"<b>\1</b>", text)
+    text = re_bold_mc.sub(r"<b>\1</b>", text)
+    return text
 
 
 def render_italic(text):
-    return re_italic.sub(r"<i>\1</i>", text)
+    text = re_italic_sc.sub(r"<i>\1</i>", text)
+    text = re_italic_mc.sub(r"<i>\1</i>", text)
+    return text
 
 
 def render_bolditalic(text):
-    return re_bolditalic.sub(r"<b><i>\1</i></b>", text)
+    text = re_bolditalic_sc.sub(r"<b><i>\1</i></b>", text)
+    text = re_bolditalic_mc.sub(r"<b><i>\1</i></b>", text)
+    return text
 
 
 def render_superscripts(text):
